==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/media/kotlin/inputs/DeinterlaceArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.media.kotlin.inputs

import com.pulumi.azurenative.media.inputs.DeinterlaceArgs.builder
import com.pulumi.azurenative.media.kotlin.enums.DeinterlaceMode
import com.pulumi.azurenative.media.kotlin.enums.DeinterlaceParity
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Describes the de-interlacing settings.
 * @property mode The deinterlacing mode. Defaults to AutoPixelAdaptive.
 * @property parity The field parity for de-interlacing, defaults to Auto.
 */
public data class DeinterlaceArgs(
    public val mode: Output<Either<String, DeinterlaceMode>>? = null,
    public val parity: Output<Either<String, DeinterlaceParity>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.media.inputs.DeinterlaceArgs> {
    override fun toJava(): com.pulumi.azurenative.media.inputs.DeinterlaceArgs =
        com.pulumi.azurenative.media.inputs.DeinterlaceArgs.builder()
            .mode(
                mode?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .parity(
                parity?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            ).build()
}

/**
 * Builder for [DeinterlaceArgs].
 */
@PulumiTagMarker
public class DeinterlaceArgsBuilder internal constructor() {
    private var mode: Output<Either<String, DeinterlaceMode>>? = null

    private var parity: Output<Either<String, DeinterlaceParity>>? = null

    /**
     * @param value The deinterlacing mode. Defaults to AutoPixelAdaptive.
     */
    @JvmName("qlqjybeyibmbiweh")
    public suspend fun mode(`value`: Output<Either<String, DeinterlaceMode>>) {
        this.mode = value
    }

    /**
     * @param value The field parity for de-interlacing, defaults to Auto.
     */
    @JvmName("andilxwfehbxpfbi")
    public suspend fun parity(`value`: Output<Either<String, DeinterlaceParity>>) {
        this.parity = value
    }

    /**
     * @param value The deinterlacing mode. Defaults to AutoPixelAdaptive.
     */
    @JvmName("gqxijksgcvksehwe")
    public suspend fun mode(`value`: Either<String, DeinterlaceMode>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.mode = mapped
    }

    /**
     * @param value The deinterlacing mode. Defaults to AutoPixelAdaptive.
     */
    @JvmName("sopomvwpmwnnlowx")
    public fun mode(`value`: String) {
        val toBeMapped = Either.ofLeft<String, DeinterlaceMode>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.mode = mapped
    }

    /**
     * @param value The deinterlacing mode. Defaults to AutoPixelAdaptive.
     */
    @JvmName("pqitdwoawvctgxfh")
    public fun mode(`value`: DeinterlaceMode) {
        val toBeMapped = Either.ofRight<String, DeinterlaceMode>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.mode = mapped
    }

    /**
     * @param value The field parity for de-interlacing, defaults to Auto.
     */
    @JvmName("tsfbxywsqdltxxhu")
    public suspend fun parity(`value`: Either<String, DeinterlaceParity>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.parity = mapped
    }

    /**
     * @param value The field parity for de-interlacing, defaults to Auto.
     */
    @JvmName("aruupgpljcbyluvs")
    public fun parity(`value`: String) {
        val toBeMapped = Either.ofLeft<String, DeinterlaceParity>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.parity = mapped
    }

    /**
     * @param value The field parity for de-interlacing, defaults to Auto.
     */
    @JvmName("vrdhkgkosulfxrlr")
    public fun parity(`value`: DeinterlaceParity) {
        val toBeMapped = Either.ofRight<String, DeinterlaceParity>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.parity = mapped
    }

    internal fun build(): DeinterlaceArgs = DeinterlaceArgs(
        mode = mode,
        parity = parity,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/media/kotlin/inputs/DeinterlaceArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.media.kotlin.inputs

import com.pulumi.azurenative.media.inputs.DeinterlaceArgs.builder
import com.pulumi.azurenative.media.kotlin.enums.DeinterlaceMode
import com.pulumi.azurenative.media.kotlin.enums.DeinterlaceParity
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Describes the de-interlacing settings.
 * @property mode The deinterlacing mode. Defaults to AutoPixelAdaptive.
 * @property parity The field parity for de-interlacing, defaults to Auto.
 */
public data class DeinterlaceArgs(
    public val mode: Output<Either<String, DeinterlaceMode>>? = null,
    public val parity: Output<Either<String, DeinterlaceParity>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.media.inputs.DeinterlaceArgs> {
    override fun toJava(): com.pulumi.azurenative.media.inputs.DeinterlaceArgs =
        com.pulumi.azurenative.media.inputs.DeinterlaceArgs.builder()
            .mode(
                mode?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .parity(
                parity?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            ).build()
}

/**
 * Builder for [DeinterlaceArgs].
 */
@PulumiTagMarker
public class DeinterlaceArgsBuilder internal constructor() {
    private var mode: Output<Either<String, DeinterlaceMode>>? = null

    private var parity: Output<Either<String, DeinterlaceParity>>? = null

    /**
     * @param value The deinterlacing mode. Defaults to AutoPixelAdaptive.
     */
    @JvmName("ydsocxsxtjeebfgo")
    public suspend fun mode(`value`: Output<Either<String, DeinterlaceMode>>) {
        this.mode = value
    }

    /**
     * @param value The field parity for de-interlacing, defaults to Auto.
     */
    @JvmName("rnkimpesllpryjan")
    public suspend fun parity(`value`: Output<Either<String, DeinterlaceParity>>) {
        this.parity = value
    }

    /**
     * @param value The deinterlacing mode. Defaults to AutoPixelAdaptive.
     */
    @JvmName("stnghwpxobslbeys")
    public suspend fun mode(`value`: Either<String, DeinterlaceMode>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.mode = mapped
    }

    /**
     * @param value The deinterlacing mode. Defaults to AutoPixelAdaptive.
     */
    @JvmName("dyakphjnvpopswhf")
    public fun mode(`value`: String) {
        val toBeMapped = Either.ofLeft<String, DeinterlaceMode>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.mode = mapped
    }

    /**
     * @param value The deinterlacing mode. Defaults to AutoPixelAdaptive.
     */
    @JvmName("rwrdvuojapbciynn")
    public fun mode(`value`: DeinterlaceMode) {
        val toBeMapped = Either.ofRight<String, DeinterlaceMode>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.mode = mapped
    }

    /**
     * @param value The field parity for de-interlacing, defaults to Auto.
     */
    @JvmName("cctmqsufrkbcdjva")
    public suspend fun parity(`value`: Either<String, DeinterlaceParity>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.parity = mapped
    }

    /**
     * @param value The field parity for de-interlacing, defaults to Auto.
     */
    @JvmName("oedjejxwtknaliat")
    public fun parity(`value`: String) {
        val toBeMapped = Either.ofLeft<String, DeinterlaceParity>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.parity = mapped
    }

    /**
     * @param value The field parity for de-interlacing, defaults to Auto.
     */
    @JvmName("vafyscslsqaawivy")
    public fun parity(`value`: DeinterlaceParity) {
        val toBeMapped = Either.ofRight<String, DeinterlaceParity>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.parity = mapped
    }

    internal fun build(): DeinterlaceArgs = DeinterlaceArgs(
        mode = mode,
        parity = parity,
    )
}
